##  Fact Sheet Attributes
Within the fact sheet body, you can configure specific fact sheet attributes such as fields and relations. For more information, refer to:
  * [Fact Sheet Fields](https://help.sap.com/docs/leanix/ea/fact-sheet-fields?locale=en-US&state=PRODUCTION&version=CLOUD "Fact sheet fields are designed for storing information on specific data points. You can configure existing fields and create custom ones.")
  * [Fact Sheet Relations](https://help.sap.com/docs/leanix/ea/fact-sheet-relations?locale=en-US&state=PRODUCTION&version=CLOUD "Relations represent connections between different fact sheets. Learn how to configure basic and advanced relations.")
